==> bootstrap-table-1.18.0.jar: META-INF/resources/webjars/bootstrap-table/1.18.0/src/locale/bootstrap-table-cs-CZ.js <==
/**
 * Bootstrap Table Czech translation
 * Author: Lukas Kral (monarcha@seznam.cz)
 * Author: Jakub Svestka <svestka1999@gmail.com>
 */

$.fn.bootstrapTable.locales['cs-CZ'] = {
  formatCopyRows () {
    return 'Copy Rows'
  },
  formatPrint () {
    return 'Print'
  },
  formatLoadingMessage () {
    return 'Čekejte, prosím'
  },
  formatRecordsPerPage (pageNumber) {
    return `${pageNumber} položek na stránku`
  },
  formatShowingRows (pageFrom, pageTo, totalRows, totalNotFiltered) {
    if (totalNotFiltered !== undefined && totalNotFiltered > 0 && totalNotFiltered > totalRows) {
      return `Zobrazena ${pageFrom}. - ${pageTo} . položka z celkových ${totalRows} (filtered from ${totalNotFiltered} total rows)`
    }

    return `Zobrazena ${pageFrom}. - ${pageTo} . položka z celkových ${totalRows}`
  },
  formatSRPaginationPreText () {
    return 'previous page'
  },
  formatSRPaginationPageText (page) {
    return `to page ${page}`
  },
  formatSRPaginationNextText () {
    return 'next page'
  },
  formatDetailPagination (totalRows) {
    return `Showing ${totalRows} rows`
  },
  formatClearSearch () {
    return 'Clear Search'
  },
  formatSearch () {
    return 'Vyhledávání'
  },
  formatNoMatches () {
    return 'Nenalezena žádná vyhovující položka'
  },
  formatPaginationSwitch () {
    return 'Skrýt/Zobrazit stránkování'
  },
  formatPaginationSwitchDown () {
    return 'Show pagination'
  },
  formatPaginationSwitchUp () {
    return 'Hide pagination'
  },
  formatRefresh () {
    return 'Aktualizovat'
  },
  formatToggle () {
    return 'Přepni'
  },
  formatToggleOn () {
    return 'Show card view'
  },
  formatToggleOff () {
    return 'Hide card view'
  },
  formatColumns () {
    return 'Sloupce'
  },
  formatColumnsToggleAll () {
    return 'Toggle all'
  },
  formatFullscreen () {
    return 'Fullscreen'
  },
  formatAllRows () {
    return 'Vše'
  },
  formatAutoRefresh () {
    return 'Auto Refresh'
  },
  formatExport () {
    return 'Export data'
  },
  formatJumpTo () {
    return 'GO'
  },
  formatAdvancedSearch () {
    return 'Advanced search'
  },
  formatAdvancedCloseButton () {
    return 'Close'
  },
  formatFilterControlSwitch () {
    return 'Hide/Show controls'
  },
  formatFilterControlSwitchHide () {
    return 'Hide controls'
  },
  formatFilterControlSwitchShow () {
    return 'Show controls'
  }
}

$.extend($.fn.bootstrapTable.defaults, $.fn.bootstrapTable.locales['cs-CZ'])

==> bootstrap-table-1.20.2.jar: META-INF/resources/webjars/bootstrap-table/1.20.2/src/locale/bootstrap-table-cs-CZ.js <==
/**
 * Bootstrap Table Czech translation
 * Author: Lukas Kral (monarcha@seznam.cz)
 * Author: Jakub Svestka <svestka1999@gmail.com>
 */

$.fn.bootstrapTable.locales['cs-CZ'] = $.fn.bootstrapTable.locales['cs'] = {
  formatCopyRows () {
    return 'Kopírovat řádky'
  },
  formatPrint () {
    return 'Tisk'
  },
  formatLoadingMessage () {
    return 'Čekejte, prosím'
  },
  formatRecordsPerPage (pageNumber) {
    return `${pageNumber} položek na stránku`
  },
  formatShowingRows (pageFrom, pageTo, totalRows, totalNotFiltered) {
    if (totalNotFiltered !== undefined && totalNotFiltered > 0 && totalNotFiltered > totalRows) {
      return `Zobrazena ${pageFrom}. - ${pageTo} . položka z celkových ${totalRows} (filtered from ${totalNotFiltered} total rows)`
    }

    return `Zobrazena ${pageFrom}. - ${pageTo} . položka z celkových ${totalRows}`
  },
  formatSRPaginationPreText () {
    return 'předchozí strana'
  },
  formatSRPaginationPageText (page) {
    return `na stranu ${page}`
  },
  formatSRPaginationNextText () {
    return 'další strana'
  },
  formatDetailPagination (totalRows) {
    return `Zobrazuji ${totalRows} řádek`
  },
  formatClearSearch () {
    return 'Smazat hledání'
  },
  formatSearch () {
    return 'Vyhledávání'
  },
  formatNoMatches () {
    return 'Nenalezena žádná vyhovující položka'
  },
  formatPaginationSwitch () {
    return 'Skrýt/Zobrazit stránkování'
  },
  formatPaginationSwitchDown () {
    return 'Zobrazit stránkování'
  },
  formatPaginationSwitchUp () {
    return 'Skrýt stránkování'
  },
  formatRefresh () {
    return 'Aktualizovat'
  },
  formatToggle () {
    return 'Přepni'
  },
  formatToggleOn () {
    return 'Zobrazit karty'
  },
  formatToggleOff () {
    return 'Zobrazit tabulku'
  },
  formatColumns () {
    return 'Sloupce'
  },
  formatColumnsToggleAll () {
    return 'Zobrazit/Skrýt vše'
  },
  formatFullscreen () {
    return 'Zapnout/Vypnout fullscreen'
  },
  formatAllRows () {
    return 'Vše'
  },
  formatAutoRefresh () {
    return 'Automatické obnovení'
  },
  formatExport () {
    return 'Export dat'
  },
  formatJumpTo () {
    return 'GO'
  },
  formatAdvancedSearch () {
    return 'Pokročilé hledání'
  },
  formatAdvancedCloseButton () {
    return 'Zavřít'
  },
  formatFilterControlSwitch () {
    return 'Skrýt/Zobrazit ovladače'
  },
  formatFilterControlSwitchHide () {
    return 'Skrýt ovladače'
  },
  formatFilterControlSwitchShow () {
    return 'Zobrazit ovladače'
  }
}

$.extend($.fn.bootstrapTable.defaults, $.fn.bootstrapTable.locales['cs-CZ'])
